Description Usage Arguments Slots
This document described the MotifSearchResult class and methods for storing results from motif finding methods (e.g. MEME, FIMO and MAST).
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | ## S4 method for signature 'MotifSearchResult'
show(object)
## S4 method for signature 'MotifSearchResult,ANY'
x[i, j, ..., drop = FALSE]
nmotif(object)
nseq(object)
motifNames(object)
sequenceNames(object)
scores(object)
pwm(object)
|
object |
MotifSearchResult object. |
x |
MotifSearchResult object. |
i |
row number (motif). |
j |
column number (sequence). |
... |
further arguments passed down to method. |
drop |
logical; whether to coerce to vector when number of columns equal one. |
infolist with result information.
sequencesAnnotatedDataFrame with sequence information.
motifsAnnotatedDataFrame with motif information.
probabilitieslist of motif probabilities.
scoreslist of motif scores.
rangesGRanges with motif hits.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.